summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormk5004.lee <mk5004.lee@samsung.com>2019-09-04 19:48:55 +0900
committermk5004.lee <mk5004.lee@samsung.com>2019-09-25 08:25:27 +0900
commit01a763662aadf99d65525577fc2b03ec186d17c2 (patch)
treec0e6f21e24f2621ad4a15c67717c4f9ce96f2b6f
parenta99021df26911e1eddcd91ca505734355308a961 (diff)
downloadnotification-01a763662aadf99d65525577fc2b03ec186d17c2.tar.gz
notification-01a763662aadf99d65525577fc2b03ec186d17c2.tar.bz2
notification-01a763662aadf99d65525577fc2b03ec186d17c2.zip
Update doxygen for notifcation_ex apis
Change-Id: I38ad1f12cb6c31b96734acfaa258660b2cab5d1f Signed-off-by: mk5004.lee <mk5004.lee@samsung.com>
-rw-r--r--notification-ex/api/notification_ex.h2
-rw-r--r--notification-ex/api/notification_ex_event_info.h2
-rw-r--r--notification-ex/api/notification_ex_item.h47
-rw-r--r--notification-ex/api/notification_ex_manager.h31
-rw-r--r--notification-ex/api/notification_ex_progress.h6
-rw-r--r--notification-ex/api/notification_ex_reporter.h16
6 files changed, 57 insertions, 47 deletions
diff --git a/notification-ex/api/notification_ex.h b/notification-ex/api/notification_ex.h
index 8ce824b..b793f35 100644
--- a/notification-ex/api/notification_ex.h
+++ b/notification-ex/api/notification_ex.h
@@ -55,4 +55,4 @@ extern "C" {
#ifdef __cplusplus
}
#endif
-#endif // __TIZEN_APPFW_NOTIFICATION_EX_H__ \ No newline at end of file
+#endif /* __TIZEN_APPFW_NOTIFICATION_EX_H__ */
diff --git a/notification-ex/api/notification_ex_event_info.h b/notification-ex/api/notification_ex_event_info.h
index 38fc1d1..59f9139 100644
--- a/notification-ex/api/notification_ex_event_info.h
+++ b/notification-ex/api/notification_ex_event_info.h
@@ -36,7 +36,7 @@ typedef enum _noti_ex_event_info_type {
NOTI_EX_EVENT_DELETE, /**< Delete the notification */
NOTI_EX_EVENT_GET, /**< Get the notification */
NOTI_EX_EVENT_ERROR, /**< Error occurs */
- NOTI_EX_EVENT_DELETE_ALL, /**< Delete all notification */
+ NOTI_EX_EVENT_DELETE_ALL, /**< Delete all notifications */
} noti_ex_event_info_type_e;
/**
diff --git a/notification-ex/api/notification_ex_manager.h b/notification-ex/api/notification_ex_manager.h
index f858ba4..f72d484 100644
--- a/notification-ex/api/notification_ex_manager.h
+++ b/notification-ex/api/notification_ex_manager.h
@@ -152,8 +152,8 @@ typedef struct {
* @param[in] user_data The user data for @a event_callbacks
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_OUT_OF_MEMORY Out of memory
* @see #noti_ex_manager_h
* @see #noti_ex_manager_events_s
@@ -240,8 +240,8 @@ int noti_ex_manager_destroy(noti_ex_manager_h handle);
* @param[out] count The count of retrieved notification items
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_item_h
* @see #noti_ex_manager_h
@@ -268,7 +268,10 @@ void _manager_events_error_cb(noti_ex_manager_h handle, noti_ex_error_e error,
for (int i = 0; i < items_count; i++) {
item = items[i];
// do something with item
+ noti_ex_item_destroy(item);
}
+
+ free(items);
}
* @endcode
*/
@@ -276,7 +279,7 @@ int noti_ex_manager_get(noti_ex_manager_h handle, noti_ex_item_h **items,
int *count);
/**
- * @brief Gets notifications with channel for the notification_ex manager.
+ * @brief Gets notifications with @a channel for the notification_ex manager.
* @details Every notification that has been sent for the manager will be retrieved.
* @since_tizen 5.5
* @privlevel public
@@ -288,8 +291,8 @@ int noti_ex_manager_get(noti_ex_manager_h handle, noti_ex_item_h **items,
* @param[out] count The count of retrieved notification items
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_item_h
* @see #noti_ex_manager_h
@@ -318,16 +321,16 @@ void _manager_events_error_cb(noti_ex_manager_h handle, noti_ex_error_e error,
for (int i = 0; i < items_count; i++) {
item = items[i];
// do something with item
+ noti_ex_item_destroy(item);
}
+
+ free(items);
}
* @endcode
*/
int noti_ex_manager_get_by_channel(noti_ex_manager_h handle, char *channel,
noti_ex_item_h **items, int *count);
-int noti_ex_manager_get_by_channel(noti_ex_manager_h handle, char *channel,
- noti_ex_item_h **items, int *count);
-
/**
* @brief Updates notification.
* @since_tizen 5.5
@@ -338,8 +341,8 @@ int noti_ex_manager_get_by_channel(noti_ex_manager_h handle, char *channel,
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_item_h
* @see #noti_ex_manager_h
@@ -385,8 +388,8 @@ int noti_ex_manager_update(noti_ex_manager_h handle, noti_ex_item_h item,
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_manager_h
* @see #noti_ex_error_e
@@ -429,8 +432,8 @@ int noti_ex_manager_delete(noti_ex_manager_h handle, noti_ex_item_h noti,
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_manager_h
* @see #noti_ex_error_e
@@ -470,8 +473,8 @@ int noti_ex_manager_delete_all(noti_ex_manager_h handle,
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_item_h
* @see #noti_ex_manager_h
@@ -516,8 +519,8 @@ int noti_ex_manager_hide(noti_ex_manager_h handle, noti_ex_item_h item,
* The @a item must be released using noti_ex_item_destroy().
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_manager_h
* @see #noti_ex_item_h
@@ -555,8 +558,8 @@ int noti_ex_manager_find_by_root_id(noti_ex_manager_h handle,
* @param[in] error The error type
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_event_info_h
* @see #noti_ex_manager_h
@@ -608,8 +611,8 @@ int noti_ex_manager_send_error(noti_ex_manager_h handle,
* @param[out] cnt The count of notifications
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_manager_h
* @see #NOTI_EX_RECEIVER_GROUP_TICKER
diff --git a/notification-ex/api/notification_ex_progress.h b/notification-ex/api/notification_ex_progress.h
index 40e48ca..f671e92 100644
--- a/notification-ex/api/notification_ex_progress.h
+++ b/notification-ex/api/notification_ex_progress.h
@@ -167,12 +167,9 @@ int noti_ex_item_progress_get_min(noti_ex_item_h handle, float *min);
*/
int noti_ex_item_progress_get_max(noti_ex_item_h handle, float *max);
-int noti_ex_item_progress_get_type(noti_ex_item_h handle, int *type);
-
-int noti_ex_item_progress_set_type(noti_ex_item_h handle, int type);
-
/**
* @brief Gets the type of progress.
+ * The type is equal to one of the values of #noti_ex_item_progress_type_e.
* @since_tizen 5.5
* @param[in] handle The notification_ex item handle
* @param[out] type The type of progress
@@ -199,6 +196,7 @@ int noti_ex_item_progress_get_type(noti_ex_item_h handle, int *type);
/**
* @brief Sets the type of progress.
+ * @details The type is equal to one of the values of #noti_ex_item_progress_type_e.
* @since_tizen 5.5
* @param[in] handle The notification_ex item handle
* @param[in] type The type of progress
diff --git a/notification-ex/api/notification_ex_reporter.h b/notification-ex/api/notification_ex_reporter.h
index f0cca8b..12835e8 100644
--- a/notification-ex/api/notification_ex_reporter.h
+++ b/notification-ex/api/notification_ex_reporter.h
@@ -101,8 +101,8 @@ typedef struct {
* @param[in] user_data The user data for @a event_callbacks
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_OUT_OF_MEMORY Out of memory
* @see #noti_ex_item_h
* @see #noti_ex_reporter_events_s
@@ -172,8 +172,8 @@ int noti_ex_reporter_destroy(noti_ex_reporter_h handle);
* @param[in] error The error type
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see #noti_ex_event_info_h
* @see #noti_ex_manager_events_s
@@ -217,8 +217,8 @@ int noti_ex_reporter_send_error(noti_ex_reporter_h handle,
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see noti_ex_reporter_create()
* @par Sample code:
@@ -260,8 +260,8 @@ int noti_ex_reporter_post(noti_ex_reporter_h handle, noti_ex_item_h noti,
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see noti_ex_reporter_create()
* @par Sample code:
@@ -308,8 +308,8 @@ int noti_ex_reporter_post_list(noti_ex_reporter_h handle, noti_ex_item_h *noti_l
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see noti_ex_reporter_create()
* @par Sample code:
@@ -349,8 +349,8 @@ int noti_ex_reporter_update(noti_ex_reporter_h handle, noti_ex_item_h noti,
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see noti_ex_reporter_create()
* @par Sample code:
@@ -388,8 +388,8 @@ int noti_ex_reporter_delete(noti_ex_reporter_h handle, noti_ex_item_h noti,
* @param[out] request_id The id of request
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see noti_ex_reporter_create()
* @par Sample code:
@@ -428,8 +428,8 @@ int noti_ex_reporter_delete_all(noti_ex_reporter_h handle,
* The @a item must be released using noti_ex_item_destroy().
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
- * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_PERMISSION_DENIED Permission deny
+ * @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @retval #NOTI_EX_ERROR_IO_ERROR IO error
* @see noti_ex_reporter_create()
* @see noti_ex_item_destroy()
diff --git a/notification-ex/api/notification_ex_item.h b/notification-ex/api/notification_ex_item.h
index 3e05500..8d54132 100644
--- a/notification-ex/api/notification_ex_item.h
+++ b/notification-ex/api/notification_ex_item.h
@@ -748,8 +748,9 @@ int noti_ex_style_get_geometry(noti_ex_style_h handle, noti_ex_geometry_h *geome
/**
* @brief Gets the background image path from style.
* @since_tizen 5.5
+ * @remarks The @a image_path should be released using free().
* @param[in] handle The notification_ex style handle
* @param[out] background_image The background image path
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
* @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
@@ -761,20 +762,20 @@ int noti_ex_style_get_geometry(noti_ex_style_h handle, noti_ex_geometry_h *geome
{
int ret;
- char *background_image;
+ char *image_path;
- ret = noti_ex_style_get_background_image(style, &background_image);
+ ret = noti_ex_style_get_background_image(style, &image_path);
}
* @endcode
*/
int noti_ex_style_get_background_image(noti_ex_style_h handle,
- char **background_image);
+ char **image_path);
/**
* @brief Sets the background image path of a style.
* @since_tizen 5.5
* @param[in] handle The notification_ex style handle
* @param[in] background_image The background image path
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
* @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
@@ -786,17 +787,21 @@ int noti_ex_style_get_background_image(noti_ex_style_h handle,
{
int ret;
- noti_ex_geometry_h geometry = NULL;
+ char *image_path[BUFLEN];
- ret = noti_ex_style_get_geometry(style, &geometry);
+ char *shared_path = app_get_shared_resource_path();
+ snprintf(image_path, BUFLEN, "%simage.png", shared_path);
+ free(shared_path);
+
+ ret = noti_ex_style_set_background_image(style, image_path);
}
* @endcode
*/
int noti_ex_style_set_background_image(noti_ex_style_h handle,
- char *background_image);
+ char *image_path);
/**
- * @brief Gets the background color from style.
+ * @brief Gets the background color of a style.
* @since_tizen 5.5
* @remarks @a color must be released using noti_ex_color_destroy().
* @param[in] handle The notification_ex style handle
@@ -842,6 +847,7 @@ int noti_ex_style_get_background_color(noti_ex_style_h handle,
ret = noti_ex_color_create(&color, 0, 0, 0, 0);
ret = noti_ex_style_set_background_color(style, color);
+ ret = noti_ex_color_destroy(color);
}
* @endcode
*/
@@ -2057,7 +2063,7 @@ int noti_ex_item_get_tag(noti_ex_item_h handle, char **tag);
int noti_ex_item_set_tag(noti_ex_item_h handle, const char *tag);
/**
- * @brief Gets a value indicating whether a notification is currently ongoing.
+ * @brief Gets the value indicating whether a notification is currently ongoing.
* @since_tizen 5.5
* @param[in] handle The notification_ex item handle
* @param[out] ongoing The state of ongoing
@@ -2080,7 +2086,7 @@ int noti_ex_item_set_tag(noti_ex_item_h handle, const char *tag);
int noti_ex_item_get_ongoing_state(noti_ex_item_h handle, bool *ongoing);
/**
- * @brief Sets a value indicating whether a notification is currently ongoing.
+ * @brief Sets the value indicating whether a notification is currently ongoing.
* @since_tizen 5.5
* @param[in] handle The notification_ex item handle
* @param[in] ongoing The state of ongoing
@@ -2102,9 +2108,8 @@ int noti_ex_item_get_ongoing_state(noti_ex_item_h handle, bool *ongoing);
int noti_ex_item_set_ongoing_state(noti_ex_item_h handle, bool ongoing);
/**
- * @brief Checks if a specified type is included in a notification_ex item.
+ * @brief Checks if an item of a specified type is included in a notification_ex item.
* @since_tizen 5.5
- * @remarks @a tag must be released using free().
* @param[in] handle The notification_ex item handle
* @param[in] type The type of a notification_ex item
* @param[out] exist The state of if a type is included
@@ -2112,6 +2117,7 @@ int noti_ex_item_set_ongoing_state(noti_ex_item_h handle, bool ongoing);
* @retval #NOTI_EX_ERROR_NONE Success
* @retval #NOTI_EX_ERROR_INVALID_PARAMETER Invalid parameter
* @see #noti_ex_item_h
+ * @see #noti_ex_item_type_e
* @par Sample code:
* @code
#include <notification_ex.h>
@@ -2128,7 +2134,8 @@ int noti_ex_item_set_ongoing_state(noti_ex_item_h handle, bool ongoing);
int noti_ex_item_check_type_exist(noti_ex_item_h handle, int type, bool *exist);
/**
- * @brief Gets the main type of notification item.
+ * @brief Gets the main type of a notification item.
+ * @details The type is equal to one of the values of #noti_ex_item_main_type_e.
* @since_tizen 5.5
* @param[in] handle The notification_ex item handle
* @param[out] type The main type
@@ -2157,12 +2164,13 @@ int noti_ex_item_get_main_type(noti_ex_item_h handle, int *type);
/**
* @brief Sets the main type of a notification item.
- * @details Use this api to configure main type among multiple items.
- * In other words, if there is only one item, it should not be used.
+ * @details Use this function to configure main type among multiple items.
+ * In other words, if there is only one item, it should not be used.
+ * The type is equal to one of the values of #noti_ex_item_main_type_e.
* @since_tizen 5.5
- * @remarks When set to a specific type, values previously set to the same type are deleted.
+ * @remarks When set to a specific type, the previous main item of the same type is canceled.
* @param[in] handle The notification_ex item handle
- * @param[in] id The id of notification_ex item
+ * @param[in] id The ID of notification_ex item
* @param[in] type The main type
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
@@ -2193,6 +2201,7 @@ int noti_ex_item_set_main_type(noti_ex_item_h handle, const char *id, int type);
* @brief Finds the notification item of the specified main type.
* @details Finds the item that matches the main type among the group items.
* @since_tizen 5.5
+ * @remarks @a handle must be released using noti_ex_item_destroy().
* @param[in] handle The notification_ex item handle
* @param[in] type The main type
* @param[out] item The notification_ex item handle
@@ -2210,7 +2219,7 @@ int noti_ex_item_set_main_type(noti_ex_item_h handle, const char *id, int type);
int type = NOTI_EX_ITEM_MAIN_TYPE_TITLE;
int ret;
- ret = noti_ex_item_get_main_type(item_handle, type, &text_item);
+ ret = noti_ex_item_find_by_main_type(item_handle, type, &text_item);
if (text_item != NULL) {
// Do something
@@ -748,8 +748,9 @@ int noti_ex_style_get_geometry(noti_ex_style_h handle, noti_ex_geometry_h *geome
* @param[in] handle The notification_ex style handle
- * @param[out] background_image The background image path
+ * @param[out] image_path The background image path
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success
@@ -761,20 +762,20 @@ int noti_ex_style_get_geometry(noti_ex_style_h handle, noti_ex_geometry_h *geome
* @since_tizen 5.5
* @param[in] handle The notification_ex style handle
- * @param[in] background_image The background image path
+ * @param[in] image_path The background image path
* @return #NOTI_EX_ERROR_NONE On success, other value on failure
* @retval #NOTI_EX_ERROR_NONE Success